//
//  XCFilelistGeneratorTests.swift
//  WeaverCodeGenTests
//
//  Created by Théophane Rupin on 2/12/19.
//

import Foundation
import XCTest
import PathKit

@testable import WeaverCodeGen

final class XCFilelistGeneratorTests: XCTestCase {

    func test_generator_should_generate_valid_xcfilelist_files() {
        let dependenciesByName = OrderedDictionary([
            ("Foo", DependencyContainer(type: Type(name: "Foo"), fileLocation: FileLocation(line: 0, file: "FakePath/Foo.swift"))),
            ("Bar", DependencyContainer(type: Type(name: "Bar"), fileLocation: FileLocation(line: 0, file: "FakePath/Bar.swift")))
        ])
        let dependencyGraph = DependencyGraph(dependenciesByName)

        let generator = XCFilelistGenerator(dependencyGraph: dependencyGraph,
                                            projectPath: Path("FakePath"),
                                            outputPath: Path("FakePath/Generated"),
                                            singleOutput: false,
                                            version: "1.0.0")
        
        let files = generator.generate()
        
        XCTAssertEqual(files.input, """
        /// This file is generated by Weaver 1.0.0
        /// DO NOT EDIT!
        $SRCROOT/Foo.swift
        $SRCROOT/Bar.swift
        """)
        
        XCTAssertEqual(files.output, """
        /// This file is generated by Weaver 1.0.0
        /// DO NOT EDIT!
        $SRCROOT/Generated/Weaver.Foo.swift
        $SRCROOT/Generated/Weaver.Bar.swift
        """)
    }
}
